@@ -3,7 +3,8 @@ from typing import List
 from fastapi import APIRouter, Depends, HTTPException, status
 from meilisearch_python_async import Client
 from meilisearch_python_async.models.index import IndexBase, IndexInfo, IndexStats
-from meilisearch_python_async.models.task import TaskId, TaskStatus
+from meilisearch_python_async.models.settings import Faceting
+from meilisearch_python_async.models.task import TaskInfo
 
 from meilisearch_fastapi._client import meilisearch_client
 from meilisearch_fastapi._config import MeiliSearchConfig, get_config
@@ -12,6 +13,7 @@ from meilisearch_fastapi.models.index import (
     DisplayedAttributesUID,
     DistinctAttribute,
     DistinctAttributeWithUID,
+    FacetingWithUID,
     FilterableAttributes,
     FilterableAttributesWithUID,
     IndexUpdate,
@@ -47,16 +49,23 @@ async def create_index(
     )
 
 
+@router.delete("/faceting/{uid}", response_model=TaskInfo, tags=["Meilisearch Index"])
+async def delete_faceting(uid: str, client: Client = Depends(meilisearch_client)) -> TaskInfo:
+    index = client.index(uid)
+
+    return await index.reset_faceting()
+
+
 @router.delete(
     "/filterable-attributes/{uid}",
-    response_model=TaskId,
+    response_model=TaskInfo,
     status_code=202,
     tags=["Meilisearch Index"],
 )
 async def delete_filterable_attributes(
     uid: str,
     client: Client = Depends(meilisearch_client),
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(uid)
 
     return await index.reset_filterable_attributes()
@@ -64,13 +73,13 @@ async def delete_filterable_attributes(
 
 @router.delete(
     "/displayed-attributes/{uid}",
-    response_model=TaskId,
+    response_model=TaskInfo,
     status_code=202,
     tags=["Meilisearch Index"],
 )
 async def delete_displayed_attributes(
     uid: str, client: Client = Depends(meilisearch_client)
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(uid)
 
     return await index.reset_displayed_attributes()
@@ -78,13 +87,13 @@ async def delete_displayed_attributes(
 
 @router.delete(
     "/attributes/distinct/{uid}",
-    response_model=TaskId,
+    response_model=TaskInfo,
     status_code=202,
     tags=["Meilisearch Index"],
 )
 async def delete_distinct_attribute(
     uid: str, client: Client = Depends(meilisearch_client)
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(uid)
 
     return await index.reset_distinct_attribute()
@@ -97,16 +106,16 @@ async def delete_if_exists(uid: str, client: Client = Depends(meilisearch_client
     return status.HTTP_204_NO_CONTENT
 
 
-@router.delete("/{uid}", response_model=TaskStatus, tags=["Meilisearch Index"])
-async def delete_index(uid: str, client: Client = Depends(meilisearch_client)) -> TaskStatus:
+@router.delete("/{uid}", response_model=TaskInfo, tags=["Meilisearch Index"])
+async def delete_index(uid: str, client: Client = Depends(meilisearch_client)) -> TaskInfo:
     index = client.index(uid)
     return await index.delete()
 
 
 @router.delete(
-    "/ranking-rules/{uid}", response_model=TaskId, status_code=202, tags=["Meilisearch Index"]
+    "/ranking-rules/{uid}", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"]
 )
-async def delete_ranking_rules(uid: str, client: Client = Depends(meilisearch_client)) -> TaskId:
+async def delete_ranking_rules(uid: str, client: Client = Depends(meilisearch_client)) -> TaskInfo:
     index = client.index(uid)
 
     return await index.reset_ranking_rules()
@@ -114,13 +123,13 @@ async def delete_ranking_rules(uid: str, client: Client = Depends(meilisearch_cl
 
 @router.delete(
     "/searchable-attributes/{uid}",
-    response_model=TaskId,
+    response_model=TaskInfo,
     status_code=202,
     tags=["Meilisearch Index"],
 )
 async def delete_searchable_attributes(
     uid: str, client: Client = Depends(meilisearch_client)
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(uid)
 
     return await index.reset_searchable_attributes()
@@ -128,45 +137,53 @@ async def delete_searchable_attributes(
 
 @router.delete(
     "/sortable-attributes/{uid}",
-    response_model=TaskId,
+    response_model=TaskInfo,
     status_code=202,
     tags=["Meilisearch Index"],
 )
 async def delete_sortable_attributes(
     uid: str, client: Client = Depends(meilisearch_client)
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(uid)
 
     return await index.reset_sortable_attributes()
 
 
 @router.delete(
-    "/stop-words/{uid}", response_model=TaskId, status_code=202, tags=["Meilisearch Index"]
+    "/stop-words/{uid}", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"]
 )
-async def delete_stop_words(uid: str, client: Client = Depends(meilisearch_client)) -> TaskId:
+async def delete_stop_words(uid: str, client: Client = Depends(meilisearch_client)) -> TaskInfo:
     index = client.index(uid)
 
     return await index.reset_stop_words()
 
 
 @router.delete(
-    "/synonyms/{uid}", response_model=TaskId, status_code=202, tags=["Meilisearch Index"]
+    "/synonyms/{uid}", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"]
 )
-async def delete_synonyms(uid: str, client: Client = Depends(meilisearch_client)) -> TaskId:
+async def delete_synonyms(uid: str, client: Client = Depends(meilisearch_client)) -> TaskInfo:
     index = client.index(uid)
 
     return await index.reset_synonyms()
 
 
 @router.delete(
-    "/typo-tolerance/{uid}", response_model=TaskId, status_code=202, tags=["Meilisearch Index"]
+    "/typo-tolerance/{uid}", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"]
 )
-async def delete_typo_tolerance(uid: str, client: Client = Depends(meilisearch_client)) -> TaskId:
+async def delete_typo_tolerance(uid: str, client: Client = Depends(meilisearch_client)) -> TaskInfo:
     index = client.index(uid)
 
     return await index.reset_typo_tolerance()
 
 
+@router.get("/faceting/{uid}", response_model=Faceting, tags=["Meilisearch Index"])
+async def get_faceting(uid: str, client: Client = Depends(meilisearch_client)) -> Faceting:
+    index = client.index(uid)
+    faceting = await index.get_faceting()
+
+    return faceting
+
+
 @router.get(
     "/filterable-attributes/{uid}", response_model=FilterableAttributes, tags=["Meilisearch Index"]
 )
@@ -302,103 +319,115 @@ async def get_typo_tolerance(
     return TypoTolerance(typo_tolerance=typo_tolerance)
 
 
-@router.put(
-    "/filterable-attributes", response_model=TaskId, status_code=202, tags=["Meilisearch Index"]
+@router.patch("/faceting", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"])
+async def update_faceting(
+    faceting: FacetingWithUID,
+    client: Client = Depends(meilisearch_client),
+) -> TaskInfo:
+    index = client.index(faceting.uid)
+
+    return await index.update_faceting(Faceting(max_values_per_facet=faceting.max_values_per_facet))
+
+
+@router.patch(
+    "/filterable-attributes", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"]
 )
 async def update_filterable_attributes(
     filterable_attributes: FilterableAttributesWithUID,
     client: Client = Depends(meilisearch_client),
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(filterable_attributes.uid)
     attributes = filterable_attributes.filterable_attributes or []
 
     return await index.update_filterable_attributes(attributes)
 
 
-@router.put(
-    "/displayed-attributes", response_model=TaskId, status_code=202, tags=["Meilisearch Index"]
+@router.patch(
+    "/displayed-attributes", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"]
 )
 async def update_displayed_attributes(
     displayed_attributes: DisplayedAttributesUID, client: Client = Depends(meilisearch_client)
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(displayed_attributes.uid)
 
     return await index.update_displayed_attributes(displayed_attributes.displayed_attributes)
 
 
-@router.put(
-    "/attributes/distinct", response_model=TaskId, status_code=202, tags=["Meilisearch Index"]
+@router.patch(
+    "/attributes/distinct", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"]
 )
 async def update_distinct_attribute(
     attribute_with_uid: DistinctAttributeWithUID, client: Client = Depends(meilisearch_client)
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(attribute_with_uid.uid)
 
     return await index.update_distinct_attribute(attribute_with_uid.attribute)
 
 
-@router.put("/", response_model=TaskId, tags=["Meilisearch Index"])
+@router.patch("/", response_model=TaskInfo, tags=["Meilisearch Index"])
 async def update_index(
     index_update: IndexUpdate,
     client: Client = Depends(meilisearch_client),
     config: MeiliSearchConfig = Depends(get_config),
-) -> TaskId:
+) -> TaskInfo:
     payload = {}
     if index_update.primary_key is not None:
         payload["primaryKey"] = index_update.primary_key
-    response = await client._http_requests.put(
+    response = await client._http_requests.patch(
         f"{config.meilisearch_url}/indexes/{index_update.uid}", payload
     )
 
-    return TaskId(**response.json())
+    return TaskInfo(**response.json())
 
 
-@router.put("/ranking-rules", response_model=TaskId, status_code=202, tags=["Meilisearch Index"])
+@router.patch(
+    "/ranking-rules", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"]
+)
 async def update_ranking_rules(
     ranking_rules: RankingRulesWithUID, client: Client = Depends(meilisearch_client)
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(ranking_rules.uid)
 
     return await index.update_ranking_rules(ranking_rules.ranking_rules)
 
 
-@router.put(
-    "/searchable-attributes", response_model=TaskId, status_code=202, tags=["Meilisearch Index"]
+@router.patch(
+    "/searchable-attributes", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"]
 )
 async def update_searchable_attributes(
     searchable_attributes: SearchableAttributesWithUID,
     client: Client = Depends(meilisearch_client),
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(searchable_attributes.uid)
 
     return await index.update_searchable_attributes(searchable_attributes.searchable_attributes)
 
 
-@router.put(
-    "/sortable-attributes", response_model=TaskId, status_code=202, tags=["Meilisearch Index"]
+@router.patch(
+    "/sortable-attributes", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"]
 )
 async def update_sortable_attributes(
     sortable_attributes: SortableAttributesWithUID, client: Client = Depends(meilisearch_client)
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(sortable_attributes.uid)
 
     return await index.update_sortable_attributes(sortable_attributes.sortable_attributes)
 
 
-@router.put("/stop-words", response_model=TaskId, status_code=202, tags=["Meilisearch Index"])
+@router.patch("/stop-words", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"])
 async def update_stop_words(
     stop_words: StopWordsWithUID, client: Client = Depends(meilisearch_client)
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(stop_words.uid)
     words = stop_words.stop_words or []
 
     return await index.update_stop_words(words)
 
 
-@router.put("/synonyms", response_model=TaskId, status_code=202, tags=["Meilisearch Index"])
+@router.patch("/synonyms", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"])
 async def update_synonyms(
     synonyms: SynonymsWithUID, client: Client = Depends(meilisearch_client)
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(synonyms.uid)
 
     if not synonyms.synonyms:
@@ -407,10 +436,12 @@ async def update_synonyms(
     return await index.update_synonyms(synonyms.synonyms)
 
 
-@router.put("/typo-tolerance", response_model=TaskId, status_code=202, tags=["Meilisearch Index"])
+@router.patch(
+    "/typo-tolerance", response_model=TaskInfo, status_code=202, tags=["Meilisearch Index"]
+)
 async def update_typo_tolerance(
     typo_tolerance: TypoToleranceWithUID, client: Client = Depends(meilisearch_client)
-) -> TaskId:
+) -> TaskInfo:
     index = client.index(typo_tolerance.uid)
 
     if not typo_tolerance.typo_tolerance:
